#include "adconfig.h"

#include <qstring.h>
#include <qstrlist.h>

#include <kconfig.h>
#include <kapp.h>
#include <kstddirs.h>
#include <kdebug.h>

AdConfig *AdConfig::instance = 0;

AdConfig::AdConfig(KConfig *config )
    : configFile(config)
{
    readSettings();
    instance = this;
}

void AdConfig::setAppList( QList<QStrList> list )
{ appList = list; }
void AdConfig::setAppCount( unsigned int count )
{ appCount = count; }
void AdConfig::setDirection( Common::Direction dir )
{ direction = dir; }
void AdConfig::setFrameAlignment( Common::Alignment align )
{ frameAlignment = align; }
void AdConfig::setPosition( int pos )
{ position = pos; }
void AdConfig::setFrameSize( const QSize& size )
{ frameSize = size; }
void AdConfig::setGeometry( const QRect& geom )
{ geometry = geom; }
void AdConfig::setStyleName( const QString& name )
{ styleName = name; }
void AdConfig::setBorderSnapZone( int zone )
{ borderSnapZone = zone; }
void AdConfig::setSystemTrayVisible( bool visible )
{ systemTrayVisible = visible; }

void AdConfig::readSettings()
{
    configFile->setGroup("Common");
    frameSize = configFile->readSizeEntry( "frameSize", new QSize(64,64) );
    geometry = configFile->readRectEntry( "geometry", new QRect(0,0,0,0) );
    appCount = configFile->readNumEntry( "appCount", 0 );
    direction =  (Common::Direction) configFile->readNumEntry(
        "direction", Common::VERTICAL );
    frameAlignment = (Common::Alignment) configFile->readNumEntry(
        "frameAlignment", Common::TOP );
    position = configFile->readNumEntry(
        "position", Common::POS_FREE_X | Common::POS_FREE_Y );
	styleName = configFile->readEntry( "styleName", "default" );
	borderSnapZone = configFile->readNumEntry( "borderSnapZone", 10 );
	systemTrayVisible = configFile->readBoolEntry( "systemTrayVisible", true );

    // read data of docked apps
    configFile->setGroup("Applications");
    QString tmp = "app%1";
    for( unsigned int i=0; i<appCount; i++ ) {
        if( !configFile->hasKey(tmp.arg(i)) ) {
            appCount=i;
            break;
        }
        else {
            QStrList strList;
            configFile->readListEntry(tmp.arg(i), strList);
            appList.append( new QStrList(strList) );
        }
    }
}

void AdConfig::writeSettings()
{
//kdDebug() << "AdConfig::writeSettings()" << endl;

    configFile->setGroup("Common");
    configFile->writeEntry( "frameSize", frameSize );
    configFile->writeEntry( "geometry", geometry );
    configFile->writeEntry( "appCount", appCount );
    configFile->writeEntry( "direction", (int) direction );
    configFile->writeEntry( "frameAlignment", (int) frameAlignment );
    configFile->writeEntry( "position", (int) position );
	configFile->writeEntry( "styleName", styleName );
	configFile->writeEntry( "borderSnapZone", borderSnapZone );
	configFile->writeEntry( "systemTrayVisible", systemTrayVisible );

    // write data of docked apps
    configFile->setGroup("Applications");
    QString tmp = "app%1";
    for( unsigned int i=0; i<appCount; i++ ) {
        configFile->writeEntry( tmp.arg(i), *(appList.at(i)) );
    }

    configFile->sync();
}


