#ifndef APPFRAME_H
#define APPFRAME_H

#include "common.h"

class QWidget;
class QString;
class QPixmap;
class QPushButton;
class QStrList;
class QPopupMenu;
class QPoint;

class KProcess;
class KWinModule;

class AdConfig;
class AppFrameDialogImpl;
class Style;

#include <qframe.h>

#include <kprocess.h>

class EmbedFrame : public QWidget
{
    Q_OBJECT
public:
    EmbedFrame( KWinModule *, QWidget *parent=0, const char* name=0 );

    void setIconPixmap( QPixmap * );
    void setBgPixmap( QPixmap * );

    void embed(WId);
    void unembed();
    WId embeddedWinId();

protected:
    void resizeEvent( QResizeEvent * );
    void paintEvent( QPaintEvent * );
    bool x11Event( XEvent * );

private:
    WId _embeddedWinId;
    QPixmap *_iconPixmap;
    QPixmap *_bgPixmap;
    KWinModule *winModule;
};


class AppFrameBar : public QWidget
{
    Q_OBJECT
public:
    AppFrameBar( QWidget *parent, const char* name );
protected:
    void paintEvent( QPaintEvent * );
private:
};


class AppFrame : public QFrame
{
    Q_OBJECT
public:
    AppFrame( AdConfig *, KWinModule *, Style *,
        QStrList list=QStrList(), QWidget *parent=0 );
    virtual ~AppFrame();

    static AppFrame *initWithDialog( AdConfig *, KWinModule *, Style *,
        QWidget * );

    bool execDialog();
    void start( int latency=100 );
    void kill( int type=SIGTERM );
    bool trySwallow( WId );
    bool tryUnswallow( WId );
    void loadIconFromConfig();
    void resizeFromConfig();
    void rearrange();
    void setStyle( Style * );

    void setName( const QString& );
    void setCommand( const QString& );
    void setWindowTitle( const QString& );
    void setIcon( const QString& );
    void setSwallowApp( bool );
    void setExecOnStartup( bool );
    void setCloseOnExit( bool );
    void setOnlyStartOnce( bool );
	void setHeightOrWidth( int );

    const QString& getName() const { return appName; }
    const QString& getCommand() const { return appCommand; }
    const QString& getWindowTitle() const { return appWindowTitle; }
    const QString& getIcon() const { return appIcon; }
    bool getSwallowApp() const { return swallowApp; }
    bool getExecOnStartup() const { return execOnStartup; }
    bool getCloseOnExit() const { return closeOnExit; }
    bool getOnlyStartOnce() const { return onlyStartOnce; }
	int getHeightOrWidth() const { return heightOrWidth; }

    AppFrameBar *getBar() { return bar; }
    QStrList *getStrList();

protected:
//    void paintEvent( QPaintEvent * );
    void resizeEvent( QResizeEvent * );
    bool eventFilter( QObject *, QEvent * );
//    void mousePressEvent( QMouseEvent * );

private:
	AppFrameDialogImpl *dialog;
	AdConfig *config;

    QPopupMenu *menu;
    QTimer *startTimer;
    KProcess *proc;
	KWinModule *winModule;

    EmbedFrame *embedFrame;
    AppFrameBar *bar;
    Style *_style;

    // the following variables will be saved in the config file
    QString
        appName,
        appCommand,
        appWindowTitle,
        appIcon;
    bool
        swallowApp,
        execOnStartup,
        closeOnExit,
        onlyStartOnce;
    int heightOrWidth;

    void initMenu();
    void showMenu(const QPoint&);
    void applyPixmaps();

protected slots:
    void slotStartProcess();
    void slotProcessExited(KProcess*);
    void slotCommandCallback(int);

signals:
    void mouseEventSignal( QWidget *, QMouseEvent * );
    void menuEventSignal( AppFrame *, Common::MenuId );
//    void menuEventSignal( AppFrame *, Common::MenuId );
    void updateSignal( AppFrame * );
};

#endif
