#include "appframedialogimpl.h"

#include <qmessagebox.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qspinbox.h>
#include <qlabel.h>

#include <kicondialog.h>
#include <klocale.h>

#include <adconfig.h>
#include <common.h>

AppFrameDialogImpl::AppFrameDialogImpl( QWidget *parent, const char *name,
    bool modal, WFlags f )
    : AppFrameDialog( parent, name, modal, f )
{
}

void AppFrameDialogImpl::setName( const QString& text )
{ nameEdit->setText( text ); }
void AppFrameDialogImpl::setCommand( const QString& text )
{ commandEdit->setText( text ); }
void AppFrameDialogImpl::setWindowTitle( const QString& text )
{ windowTitleEdit->setText( text ); }
void AppFrameDialogImpl::setIcon( const QString& text )
{ iconButton->setIcon( text ); }
void AppFrameDialogImpl::setSwallowApp( bool enable )
{ swallowCheckBox->setChecked(enable); }
void AppFrameDialogImpl::setExecOnStartup( bool enable )
{ execOnStartupCheckBox->setChecked(enable); }
void AppFrameDialogImpl::setCloseOnExit( bool enable )
{ closeOnExitCheckBox->setChecked(enable); }
void AppFrameDialogImpl::setOnlyStartOnce( bool enable )
{ startOnceCheckBox->setChecked(enable); }
void AppFrameDialogImpl::setHeightOrWidth( int value )
{ heightOrWidthSpinBox->setValue(value); }

QString AppFrameDialogImpl::getName() const
{ return nameEdit->text(); }
QString AppFrameDialogImpl::getCommand() const
{ return commandEdit->text(); }
QString AppFrameDialogImpl::getWindowTitle() const
{ return windowTitleEdit->text(); }
QString AppFrameDialogImpl::getIcon() const
{ return iconButton->icon(); }
bool AppFrameDialogImpl::getSwallowApp() const
{ return swallowCheckBox->isChecked(); }
bool AppFrameDialogImpl::getExecOnStartup() const
{ return execOnStartupCheckBox->isChecked(); }
bool AppFrameDialogImpl::getCloseOnExit() const
{ return closeOnExitCheckBox->isChecked(); }
bool AppFrameDialogImpl::getOnlyStartOnce() const
{ return startOnceCheckBox->isChecked(); }
int AppFrameDialogImpl::getHeightOrWidth() const
{ return heightOrWidthSpinBox->value(); }

void AppFrameDialogImpl::setHeightOrWidthLabelText( const QString& text )
{
	heightOrWidthLabel->setText(text);
}

void AppFrameDialogImpl::slotCheck()
{
    QString message = "";

    if( getCloseOnExit() && (!getOnlyStartOnce()) )
        message += i18n("You cannot choose \"close app on exit\"\n"
            "without \"only start app once\"!\n\n");

    if( message != "" ) {
        QMessageBox::information(this, i18n("Warning"), message, QMessageBox::Ok );
        return;
    }

    accept();
}

void AppFrameDialogImpl::slotClear()
{
    setName("");
    setCommand("");
    setWindowTitle("");
    setIcon("");
    AdConfig *conf = AdConfig::getInstance();
	if( conf->getDirection() == Common::HORIZONTAL )
		heightOrWidthSpinBox->setValue(conf->getFrameSize().width());
	else
		heightOrWidthSpinBox->setValue(conf->getFrameSize().height());
}

void AppFrameDialogImpl::slotSelect()
{
    WId window = Tools::selectWindow();
    QString property;

    property = Tools::getWindowProperty(window, "WM_COMMAND");
    if( !property.isNull() ) {
        setCommand(property);
        int pos = property.find(' ');
        if( pos!=-1 )
            property.truncate(pos);
        setName(property);
    }
    else { // try out class strings
        property = Tools::getWindowProperty(window, "WM_CLASS");
        int pos = property.find(' ');
        if( pos!=-1 )
            property.truncate(pos);
        setName(property);
        setCommand(property);
    }

    property = Tools::getWindowProperty(window, "WM_NAME");
    if( !property.isNull() ) {
        setWindowTitle(property);
    }
}
