#include "common.h"

#include <qstring.h>
#include <qpixmap.h>
#include <qwmatrix.h>

#include <kdebug.h>

#include <X11/Xutil.h>
#include <X11/Xatom.h>
#include <X11/Xmu/WinUtil.h>
#include <X11/cursorfont.h>

bool Tools::string2Bool( const char *string ) {
    if(strcmp(string, "true")==0) return true;
    else return false;
}

QString Tools::bool2String( bool value ) {
    if(value) return "true";
    else return "false";
}

Window Tools::selectWindow() {
    Display *dpy = qt_xdisplay();
    int screen = DefaultScreen(dpy);

    // this part of the program is taken from 'xprop'

    int status;
    Cursor cursor;
    XEvent event;
    Window
        target_win = None,
        root = RootWindow(dpy,screen);

    int buttons = 0;

    /* Make the target cursor */
    cursor = XCreateFontCursor(dpy, XC_crosshair);

    /* Grab the pointer using target cursor, letting it room all over */
    status = XGrabPointer(dpy, root, false,
        ButtonPressMask|ButtonReleaseMask, GrabModeSync,
        GrabModeAsync, root, cursor, CurrentTime);
    if (status != GrabSuccess)
		kdError() << "Can't grab the mouse." << "\n";

    /* Let the user select a window... */
    while ((target_win == None) || (buttons != 0)) {
        /* allow one more event */
        XAllowEvents(dpy, SyncPointer, CurrentTime);
        XWindowEvent(dpy, root, ButtonPressMask|ButtonReleaseMask, &event);
        switch (event.type) {
            case ButtonPress:
                if (target_win == None) {
                    target_win = event.xbutton.subwindow; /* window selected */
                    if (target_win == None) target_win = root;
                }
                buttons++;
                break;
            case ButtonRelease:
                if (buttons > 0) /* there may have been some down before we started */
                    buttons--;
                break;
        }
    }

    XUngrabPointer(dpy, CurrentTime);      /* Done with pointer */

    int dummyi;
    unsigned int dummy;

    if (XGetGeometry (dpy, target_win, &root, &dummyi, &dummyi,
            &dummy, &dummy, &dummy, &dummy) &&
            target_win != root )
        target_win = XmuClientWindow(dpy, target_win);

    return target_win;
}

QString Tools::getWindowProperty( Window w, const QString& property ) {
    QString prop_return = "";

    Atom atom = 0;

    if( (atom = XInternAtom(qt_xdisplay(), property.latin1(), true)) ) {
        int max_len = 100; // == 400 chars in XGetWindowProperty
        Atom type;
        int format;
        unsigned long nitems;
        unsigned long bytes_after;
        unsigned char *prop;

        int status = XGetWindowProperty(
            qt_xdisplay(), w, atom, 0, max_len, false, AnyPropertyType,
            &type, &format, &nitems, &bytes_after,
            &prop );

        if( (status==Success) && (format==8) && (nitems!=0) ) {
            // if everything works well prop is a char* in which single words
            // are separated by `\0`s
            for(unsigned int i=0; i<nitems-1; i++)
                if(prop[i]=='\0') prop[i]=' ';
            prop_return = (char*) prop;
        }
    }

    return prop_return;
}

Window Tools::getWindowByName(Display *dpy, Window top, const QString& name) {
    // taken from dsimple.c of the XFree project

    Window *children, dummy;
    unsigned int nchildren;
    Window w=0;
    char *window_name;

    if ( XFetchName(dpy, top, &window_name) &&
        !strcmp(window_name, name.latin1()) )
    return(top);

    if (!XQueryTree(dpy, top, &dummy, &dummy, &children, &nchildren))
    return(0);

    for (unsigned int i=0; i<nchildren; i++) {
        w = getWindowByName(dpy, children[i], name);
        if (w)
            break;
    }
    if (children) XFree ((char *)children);
    return(w);
}

QPixmap Tools::getScaledPixmap(
    const QPixmap& pm, const QSize& size, bool enlarge)
{
    if( pm.size() != size ) {
        if( enlarge ||
            ((pm.width() > size.width()) ||
             (pm.height() > size.height())) ) {
            QWMatrix m;
            float x = (float) size.width() / pm.width();
            float y = (float) size.height() / pm.height();
            m.scale( x, y );
            return pm.xForm(m);
        }
    }

    return pm;
}
