/***************************************************************************
                          parser.cpp  -  description
                             -------------------
    begin                : Thu Jan 25 2001
    copyright            : (C) 2001 by Henning Burchardt
    email                : h_burchardt@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "parser.h"

#include <qstring.h>
#include <qtextstream.h>
#include <qregexp.h>

#include <kdebug.h>

AdSimpleParser::AdSimpleParser( QTextStream *stream )
    : _text( stream )
{
}

void AdSimpleParser::parse()
{
    static QRegExp
        groupRegExp("\\[.+\\]"),
        keyValueRegExp(".+=\".+\""),
        valueRegExp("\".+\"");

    QString line = QString::null;
    QString group = QString::null;
    QMap<QString,QString> keyValueMap;
    while( (line = _text->readLine()) != QString::null )
    {
        if( line.contains(groupRegExp) )
        {
            if( group != QString::null )
            {
                _groupMap.insert(group, keyValueMap);
                keyValueMap.clear();
            }
            int pos, len;
            pos = groupRegExp.match(line, 0, &len);
            group = line.mid(pos+1,len-2);
//            kdDebug() << group << endl;
        }
        else if( line.contains(keyValueRegExp) )
        {
            int pos, len;
            pos = line.find("=");
            QString key = line.mid(0, pos);
            pos = valueRegExp.match(line, 0, &len);
            QString value = line.mid(pos+1, len-2);
            keyValueMap.insert(key, value);
//            kdDebug() << key << "/" << value << endl;
        }
    } // end of while

    // add the last group
    if( group != QString::null )
    {
        _groupMap.insert(group, keyValueMap);
        keyValueMap.clear();
    }

}

QString AdSimpleParser::getValue( const QString& group, const QString& key )
{
    if( ! _groupMap.contains(group) )
        return QString::null;

    QMap<QString,QString> keyValueMap = _groupMap[group];
    if( ! keyValueMap.contains(key) )
        return QString::null;

    return keyValueMap[key];
}
