#include "prefsdialogimpl.h"

#include <qradiobutton.h>
#include <qspinbox.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qcheckbox.h>

#include <kfiledialog.h>
#include <kdebug.h>

PrefsDialogImpl::PrefsDialogImpl( QWidget *parent, const char *name,
    bool modal, WFlags f )
    : PrefsDialog( parent, name, modal, f )
{
}

Common::Direction PrefsDialogImpl::getDirection() const
{
    if( verticalRadioButton->isChecked() ) return Common::VERTICAL;
    else return Common::HORIZONTAL;
}

int PrefsDialogImpl::getPosition() const
{
    int pos=0;
    if( posXLeftRadioButton->isChecked() )
        pos |= Common::POS_LEFT;
    else if( posXRightRadioButton->isChecked() )
        pos |= Common::POS_RIGHT;
    else
        pos |= Common::POS_FREE_X;

    if( posYTopRadioButton->isChecked() )
        pos |= Common::POS_TOP;
    else if( posYBottomRadioButton->isChecked() )
        pos |= Common::POS_BOTTOM;
    else
        pos |= Common::POS_FREE_Y;

    return pos;
}

Common::Alignment PrefsDialogImpl::getFrameAlignment() const
{
    if( topRadioButton->isChecked() ) return Common::TOP;
    else if( bottomRadioButton->isChecked() ) return Common::BOTTOM;
    else if( leftRadioButton->isChecked() ) return Common::LEFT;
    else if( rightRadioButton->isChecked() ) return Common::RIGHT;

    return Common::TOP;
}

QSize PrefsDialogImpl::getFrameSize() const
{ return QSize( widthSpinBox->value(), heightSpinBox->value() ); }

QString PrefsDialogImpl::getStyleName() const
{ return styleComboBox->currentText(); }

bool PrefsDialogImpl::isSystemTrayVisible() const
{ return systemTrayVisibleCheckBox->isChecked(); }

void PrefsDialogImpl::setDirection( Common::Direction dir )
{
    if(dir==Common::VERTICAL) verticalRadioButton->setChecked(true);
    else horizontalRadioButton->setChecked(true);
}

void PrefsDialogImpl::setPosition( int pos )
{
    if( pos & Common::POS_LEFT )
        posXLeftRadioButton->setChecked(true);
    else if( pos & Common::POS_RIGHT )
        posXRightRadioButton->setChecked(true);
    else
        posXFreeRadioButton->setChecked(true);

    if( pos & Common::POS_TOP )
        posYTopRadioButton->setChecked(true);
    else if( pos & Common::POS_BOTTOM )
        posYBottomRadioButton->setChecked(true);
    else
        posYFreeRadioButton->setChecked(true);
}

void PrefsDialogImpl::setFrameAlignment( Common::Alignment align )
{
    switch( align ) {
        case Common::TOP: topRadioButton->setChecked(true);
            break;
        case Common::BOTTOM: bottomRadioButton->setChecked(true);
            break;
        case Common::LEFT: leftRadioButton->setChecked(true);
            break;
        case Common::RIGHT: rightRadioButton->setChecked(true);
            break;
    }
}

void PrefsDialogImpl::setFrameSize( const QSize& size )
{
    widthSpinBox->setValue( size.width() );
    heightSpinBox->setValue( size.height() );
}

void PrefsDialogImpl::setStyleNames( const QStringList& list )
{
    styleComboBox->clear();
    styleComboBox->insertStringList(list);
}

void PrefsDialogImpl::setCurrentStyleName( const QString& style )
{
//kdDebug() << style << endl;
    for( int i=0; i<styleComboBox->count(); i++ )
    {
        if( styleComboBox->text(i) == style )
        {
//kdDebug() << styleComboBox->text(i) << endl;
            styleComboBox->setCurrentItem(i);
            break;
        }
    }
}

void PrefsDialogImpl::setSystemTrayVisible( bool visible )
{
	systemTrayVisibleCheckBox->setChecked( visible );
}

#include "prefsdialogimpl.moc"
