#ifndef __toplevel_h
#define __toplevel_h

#include "common.h"

#include <qlist.h>
#include <qframe.h>

#include <kmainwindow.h>
#include <ksystemtray.h>

class QStrList;
class QToolButton;
class QPixmap;

class KWinModule;
class KAboutData;
class KSystemTray;
class KPopupMenu;

class AppFrame;
class AdConfig;
class PrefsDialogImpl;
class AdSysTray;

class ToplevelButton : public QFrame
{
	Q_OBJECT
public:
	ToplevelButton( QWidget *parent=0, const char *name=0 );
protected:
	void mousePressEvent( QMouseEvent * );
	void paintEvent( QPaintEvent * );
signals:
	void clickedSignal();
};

class ToplevelBar : public QFrame
{
    Q_OBJECT
public:
    ToplevelBar( QWidget *parent=0, const char *name=0 );

protected:
    void paintEvent( QPaintEvent * );
};

class Style
{
public:
	Style( QPixmap *appframePixap,
		QPixmap *appframeVerticalBarPixmap,
		QPixmap *appframeHorizontalBarPixmap,
		QPixmap *toplevelVerticalBarPixmap,
		QPixmap *toplevelHorizontalBarPixmap,
		QPixmap *toplevelButtonPixmap );
	Style();
    ~Style();

	QPixmap *getAppframePixmap() const
	{ return _appframePixmap; }
	QPixmap *getAppframeVerticalBarPixmap() const
	{ return _appframeVerticalBarPixmap; }
	QPixmap *getAppframeHorizontalBarPixmap() const
	{ return _appframeHorizontalBarPixmap; }
	QPixmap *getToplevelVerticalBarPixmap() const
	{ return _toplevelVerticalBarPixmap; }
	QPixmap *getToplevelHorizontalBarPixmap() const
	{ return _toplevelHorizontalBarPixmap; }
	QPixmap *getToplevelButtonPixmap() const
	{ return _toplevelButtonPixmap; }
	
private:
	QPixmap	*_appframePixmap;
	QPixmap *_appframeVerticalBarPixmap;
	QPixmap *_appframeHorizontalBarPixmap;
	QPixmap *_toplevelVerticalBarPixmap;
	QPixmap *_toplevelHorizontalBarPixmap;
	QPixmap *_toplevelButtonPixmap;
};

class Toplevel : public KMainWindow
{
    Q_OBJECT
public:
    Toplevel( AdConfig *config, KAboutData *data );
    virtual ~Toplevel();

    QList<AppFrame> getAppFrameList() { return appFrameList; }
    QWidget *getMainWidget() { return appFrameWidget; }
    Style *getStyle() { return _style; }

	void setStyle( Style * );
    void resizeAppFramesFromConfig();
    void rearrangeAppFrames();
    void addAppFrame( AppFrame * );
    void addAppFrame( QStrList );
    bool trySwallow(WId);
    bool tryUnswallow(WId);
    void rearrange();
    void reposition();
    void updateConfig();

protected:
    bool eventFilter( QObject *, QEvent * );
    bool queryExit();

private:
    AdConfig *_config;
    ToplevelBar *menubar;
	ToplevelButton *minimizeButton;
	Style *_style;
	PrefsDialogImpl *_prefsDlg;
    AdSysTray *_sysTray;

    QWidget *appFrameWidget;
    KPopupMenu *menu;
    QList<AppFrame> appFrameList;
    KWinModule *_winModule;
    KAboutData *_about;

    Style *loadStyle( const QString& );
    void menuEvent(Common::MenuId);
    void initMenu();
    void applyStyle();
    void applyPixmaps();
    void updateSysTray();
    void createAppFrame();
    void about();
    void help();
    void preferences();
    void save();
    void quit();
    int getAppFrameIndexByPos(int pos, bool xAxis);

protected slots:
    void slotWindowAdded( WId );
    void slotWorkAreaChanged();
    void slotAppFrameMouseEvent( QWidget *, QMouseEvent * );
    void slotAppFrameMenuEvent( AppFrame *, Common::MenuId );
    void slotAppFrameUpdated( AppFrame * );
    void slotCommandCallback( int id );
	void slotMinimize();
    void slotPrefsDlgOk();
    void slotPrefsDlgApply();
    void slotPrefsDlgCancel();
    void slotSysTrayMouseEvent( QMouseEvent * );

};

class AdSysTray : public KSystemTray
{
    Q_OBJECT
public:
    enum Pixmap { PmNormal, PmDarker };
    AdSysTray( QPixmap *, QPixmap *, QWidget * , const char * );
    void setPixmap( AdSysTray::Pixmap );
protected:
    void mousePressEvent( QMouseEvent * );
    void paintEvent( QPaintEvent * );
private:
    AdSysTray::Pixmap _pm;
    QPixmap *_normalPm;
    QPixmap *_darkerPm;
signals:
    void mouseEventSignal( QMouseEvent * );
};

#endif

